We aspire to deal with all pull requests in a timely manner. Please be patient.

Ideally, pull requests will respect the underlying intrastructure of `uravu`, pass all tests, pass a `flake8` run, and be well documented.
However, please do not let this put novice programmers off contributing. 
All contributions are welcome.